@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.0701';
+our $VERSION = '0.08';
 
 use Moo;
 use strictures 2;
@@ -169,6 +169,32 @@ sub nrc_get_word {
         : undef;
 }
 
+
+sub get_sentence {
+    my ( $self, $sentence ) = @_;
+
+    $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
+    my @words = split /\s+/, $sentence;
+
+    my %score;
+    $score{$_} = $self->get_word($_) for @words;
+
+    return \%score;
+}
+
+
+sub nrc_get_sentence {
+    my ( $self, $sentence ) = @_;
+
+    $sentence =~ s/[[:punct:]]//g;  # Drop punctuation
+    my @words = split /\s+/, $sentence;
+
+    my %score;
+    $score{$_} = $self->nrc_get_word($_) for @words;
+
+    return \%score;
+}
+
 1;
 
 __END__
@@ -183,7 +209,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.0701
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -294,6 +320,18 @@ positive/negative keys.  If the word does not exist, return C<undef>.
 Get the NRC emotional sentiment for a given word.  Return a HashRef of the NRC
 emotions.  If the word does not exist, return C<undef>.
 
+=head2 get_sentence()
+
+  $values = $opinion->get_sentence($sentence);
+
+Return the positive/negative values for the words of the given sentence.
+
+=head2 nrc_get_sentence()
+
+  $values = $opinion->nrc_get_sentence($sentence);
+
+Return the NRC emotion values for each word of the given sentence.
+
 =head1 SEE ALSO
 
 L<Moo>
